@@ -1,20 +1,21 @@
 package Module::Install::Admin::ScanDeps;
 
-use Module::Install::Base;
-@ISA = qw(Module::Install::Base);
-
-$VERSION = '0.76';
-
 use strict;
+use Module::Install::Base ();
+use vars qw{$VERSION @ISA};
+BEGIN {
+	$VERSION = '1.10';
+	@ISA = qw(Module::Install::Base);
+}
 
 sub scan_dependencies {
-    my ($self, $pkg, $perl_version) = @_;
+    my ($self, $pkg, $perl_version, $pkg_version) = @_;
 
     return if $pkg eq 'perl';
 
     $perl_version ||= $self->perl_version or die <<'END_MESSAGE';
 Please first specify a required perl version, like this:
-    requires( perl => '5.005' );
+    perl_version('5.005');
 END_MESSAGE
     $perl_version =~ s{^(\d+)\.(\d+)\.(\d+)}{$1 + $2/1_000 + $3/1_000_000}e;
 
@@ -24,14 +25,16 @@ END_MESSAGE
     die "Module::CoreList has no information on perl $perl_version"
         unless exists $Module::CoreList::version{$perl_version};
 
-    if (my $min_version = Module::CoreList->first_release($pkg)) {
+    if (my $min_version = Module::CoreList->first_release($pkg, $pkg_version)) {
         return if $min_version <= $perl_version;
     }
 
-    my @files = scalar $self->admin->find_in_inc($pkg)
+    # We only need the first one in the @INC here
+    my $file = $self->admin->find_in_inc($pkg)
         or die "Cannot find $pkg in \@INC";
-    my %result = ($pkg => $files[0]);
+    my %result = ($pkg => $file);
 
+    my @files = ($file);
     while (@files) {
         my $deps = Module::ScanDeps::scan_deps(
             files   => \@files,
@@ -77,3 +80,20 @@ END_MESSAGE
 }
 
 1;
+
+__END__
+
+=pod
+
+=encoding UTF-8
+
+=head1 COPYRIGHT
+
+Copyright 2008 - 2014 Adam Kennedy.
+
+=head1 LICENSE
+
+This library is free software; you can redistribute it and/or modify
+it under the same terms as Perl itself.
+
+=cut
